keynames is a crate to convert keyboard scan codes to OS-defined key strings
Modules
- errors
- Errors during creation of a KeyLayout
- key_
layout - The KeyLayout struct and supporting elements
keynames is a crate to convert keyboard scan codes to OS-defined key strings